@@ -1,24 +1,9 @@
-/********************************************************************
- KSld - the KDE Screenlocker Daemon
- This file is part of the KDE project.
+/*
+SPDX-FileCopyrightText: 2011 Martin Gräßlin <mgraesslin@kde.org>
 
-Copyright (C) 2011 Martin Gräßlin <mgraesslin@kde.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
-#ifndef SCREENLOCKER_GREETERAPP_H
-#define SCREENLOCKER_GREETERAPP_H
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
+#pragma once
 
 #include <KDeclarative/QmlObjectSharedEngine>
 #include <KPackage/PackageStructure>
@@ -124,5 +109,3 @@ private:
     LnFIntegration *m_lnfIntegration;
 };
 } // namespace
-
-#endif // SCREENLOCKER_GREETERAPP_H
